@@ -5,17 +5,16 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import sys
-import os
 import subprocess
 import inspect
 import itertools
 from operator import itemgetter
-import json
 from netCDF4 import Dataset
 from lxml import etree as ET
 from compliance_checker.base import fix_return_value, Result
 from owslib.sos import SensorObservationService
 from owslib.swe.sensor.sml import SensorML
+from compliance_checker.protocols import opendap, netcdf, cdl
 try:
     from urlparse import urlparse
 except ImportError:
@@ -128,7 +127,7 @@ class CheckSuite(object):
         Returns a dictionary mapping checker names to a 2-tuple of their grouped scores and errors/exceptions while running checks.
         """
 
-        ret_val  = {}
+        ret_val = {}
         checkers = self._get_valid_checkers(ds, checker_names)
 
         if len(checkers) == 0:
@@ -139,9 +138,9 @@ class CheckSuite(object):
             checker = checker_class()
             checker.setup(ds)
 
-            checks             = self._get_checks(checker, skip_checks)
-            vals               = []
-            errs               = {}   # check method name -> (exc, traceback)
+            checks = self._get_checks(checker, skip_checks)
+            vals = []
+            errs = {}   # check method name -> (exc, traceback)
 
             for c in checks:
                 try:
@@ -195,14 +194,14 @@ class CheckSuite(object):
 
         aggregates['scored_points'] = 0
         aggregates['possible_points'] = 0
-        high_priorities   = []
+        high_priorities = []
         medium_priorities = []
-        low_priorities    = []
-        all_priorities    = []
+        low_priorities = []
+        all_priorities = []
 
-        aggregates['high_count']   = 0
+        aggregates['high_count'] = 0
         aggregates['medium_count'] = 0
-        aggregates['low_count']    = 0
+        aggregates['low_count'] = 0
 
         def named_function(result):
             for child in result.children:
@@ -238,12 +237,12 @@ class CheckSuite(object):
             # do total the points and display the messages
             named_function(res)
 
-        aggregates['high_priorities']   = high_priorities
+        aggregates['high_priorities'] = high_priorities
         aggregates['medium_priorities'] = medium_priorities
-        aggregates['low_priorities']    = low_priorities
-        aggregates['all_priorities']    = all_priorities
-        aggregates['testname']          = check_name
-        aggregates['source_name']       = source_name
+        aggregates['low_priorities'] = low_priorities
+        aggregates['all_priorities'] = all_priorities
+        aggregates['testname'] = check_name
+        aggregates['source_name'] = source_name
         return aggregates
 
     def dict_output(self, check_name, groups, source_name, limit):
@@ -337,31 +336,31 @@ class CheckSuite(object):
             print('\n')
             priority_flag = 3
             for x in range(len(score_list)):
-                if score_list[x][1] == 3 and limit <= 3 :
+                if score_list[x][1] == 3 and limit <= 3:
                     if priority_flag == 3:
                         print('{:^80}'.format("High Priority"))
                         print("-" * 80)
                         print('%-36s:%8s:%6s' % ('    Name', 'Priority', 'Score'))
                         priority_flag -= 1
-                    print('%-40s:%s:%6s/%1s'  % (score_list[x][0][0:39], score_list[x][1], score_list[x][2][0], score_list[x][2][1]))
+                    print('%-40s:%s:%6s/%1s' % (score_list[x][0][0:39], score_list[x][1], score_list[x][2][0], score_list[x][2][1]))
 
-                elif score_list[x][1] == 2 and limit <= 2 :
+                elif score_list[x][1] == 2 and limit <= 2:
                     if priority_flag == 2:
                         print('\n')
                         print('{:^80}'.format("Medium Priority"))
                         print("-" * 80)
                         print('%-36s:%8s:%6s' % ('    Name', 'Priority', 'Score'))
                         priority_flag -= 1
-                    print('%-40s:%s:%6s/%1s'  % (score_list[x][0][0:39], score_list[x][1], score_list[x][2][0], score_list[x][2][1]))
+                    print('%-40s:%s:%6s/%1s' % (score_list[x][0][0:39], score_list[x][1], score_list[x][2][0], score_list[x][2][1]))
 
-                elif score_list[x][1] == 1 and limit == 1 :
+                elif score_list[x][1] == 1 and limit == 1:
                     if priority_flag == 1:
                         print('\n')
                         print('{:^80}'.format("Low Priority"))
                         print("-" * 80)
                         print('%-36s:%8s:%6s' % ('    Name', 'Priority', 'Score'))
                         priority_flag -= 1
-                    print('%-40s:%s:%6s/%1s'  % (score_list[x][0][0:39], score_list[x][1], score_list[x][2][0], score_list[x][2][1]))
+                    print('%-40s:%s:%6s/%1s' % (score_list[x][0][0:39], score_list[x][1], score_list[x][2][0], score_list[x][2][1]))
 
                 elif score_list[x][1] == 1 and limit == 1 and priority_flag == 2:
                     print('{:^80}'.format('No medium priority tests present'))
@@ -452,7 +451,7 @@ class CheckSuite(object):
             if res.children:
                 self.print_routine(res.children, indent + 1, priority_flag)
 
-    def reasoning_routine(self, list_of_results, indent, line = True):
+    def reasoning_routine(self, list_of_results, indent, line=True):
         """
         print routine performed
         """
@@ -466,13 +465,18 @@ class CheckSuite(object):
         grouped_sorted = []
         grouped_sorted = sorted(list_of_results, key=weight_func, reverse=True)
 
-        wrapper = textwrap.TextWrapper(initial_indent = '', width = 80, subsequent_indent = ' ' * 54)
+        wrapper = textwrap.TextWrapper(initial_indent='', width=80, subsequent_indent=' ' * 54)
         for res in grouped_sorted:
             if (res.value[0] != res.value[1]) and not res.msgs:
                 print('%-39s:%1s:%6s/%2s : %s' % ((indent * '    ' + res.name)[0:39], res.weight, res.value[0], res.value[1], ' '))
 
             if (res.value[0] != res.value[1]) and res.msgs:
-                print(wrapper.fill('%-39s:%1s:%6s/%2s : %s' % ((indent * '    ' + res.name)[0:39], res.weight, res.value[0], res.value[1], ", ".join(res.msgs))))
+                print(wrapper.fill('%-39s:%1s:%6s/%2s : %s' %
+                      ((indent * '    ' + res.name)[0:39],
+                       res.weight,
+                       res.value[0],
+                       res.value[1],
+                       ", ".join(res.msgs))))
 
             if res.children:
                 self.reasoning_routine(res.children, indent + 1, False)
@@ -511,87 +515,48 @@ class CheckSuite(object):
 
     def load_dataset(self, ds_str):
         """
-        Helper method to load a dataset or SOS GC/DS url.
+        Returns an instantiated instance of either a netCDF file or an SOS
+        mapped DS object.
+
+        :param str ds_str: URL of the resource to load
         """
-        ds = None
-        # try to figure out if this is a local NetCDF Dataset, a remote one, or an SOS GC/DS url
-        doc = None
+        # If it's a remote URL load it as a remote resource, otherwise treat it
+        # as a local resource.
         pr = urlparse(ds_str)
-        if pr.netloc:       # looks like a remote url
-            rhead = requests.head(ds_str, allow_redirects=True)
-            # if we get a 400 here, it's likely a Dataset openable OpenDAP url
-            if rhead.status_code == 400 or rhead.status_code == 401:
-                pass
-            elif rhead.status_code == 200 and rhead.headers['content-type'] == 'text/xml':
-                # probably interesting, grab it
-                r = requests.get(ds_str)
-                r.raise_for_status()
+        if pr.netloc:
+            return self.load_remote_dataset(ds_str)
+        return self.load_local_dataset(ds_str)
 
-                # need to use content to get bytes, as text will return unicode
-                # in Python3, which will break etree.fromstring if encoding
-                # is also declared in the XML doc
-                doc = r.content
-            else:
-                raise Exception("Could not understand response code %s and content-type %s" % (rhead.status_code, rhead.headers.get('content-type', 'none')))
+    def load_remote_dataset(self, ds_str):
+        '''
+        Returns a dataset instance for the remote resource, either OPeNDAP or SOS
+
+        :param str ds_str: URL to the remote resource
+        '''
+        if opendap.is_opendap(ds_str):
+            return Dataset(ds_str)
         else:
-            def is_binary_string(bts):
-                # do a cheap imitation of libmagic
-                # http://stackoverflow.com/a/7392391/84732
-                if sys.version_info >= (3, ):
-                    join_str = ''
-                    textchars = join_str.join(map(chr, [7, 8, 9, 10, 12, 13, 27]
-                                                  + list(range(0x20, 0x100)))).encode()
-                else:
-                    # because of `unicode_literals` import, we need to convert
-                    # to a Py2 string/bytes
-                    join_str = str('')
-                    textchars = join_str.join(map(chr, [7, 8, 9, 10, 12, 13, 27]
-                                                  + list(range(0x20, 0x100))))
-                return bool(bts.translate(None, textchars))
+            # Check if the HTTP response is XML, if it is, it's likely SOS so
+            # we'll attempt to parse the response as SOS
+            response = requests.get(ds_str, allow_redirects=True)
+            if 'text/xml' in response.headers['content-type']:
+                return self.process_doc(response.content)
 
-            def is_cdl_file(filename, data):
-                '''
-                Quick check for .cdl ascii file
+            raise ValueError("Unknown service with content-type: {}".format(response.headers['content-type']))
 
-                Example:
-                    netcdf sample_file {
-                    dimensions:
-                        name_strlen = 7 ;
-                        time = 96 ;
-                    variables:
-                        float lat ;
-                            lat:units = "degrees_north" ;
-                            lat:standard_name = "latitude" ;
-                            lat:long_name = "station latitude" ;
-                    etc...
+    def load_local_dataset(self, ds_str):
+        '''
+        Returns a dataset instance for the local resource
 
-                :param str filename: Absolute path of file to check
-                :param str data: First chuck of data from file to check
-                '''
-                if os.path.splitext(filename)[-1] == '.cdl':
-                    return True
-                if data.startswith(b'netcdf') or b'dimensions' in data:
-                    return True
-                return False
+        :param ds_str: Path to the resource
+        '''
+        if cdl.is_cdl(ds_str):
+            ds_str = self.generate_dataset(ds_str)
 
-            with open(ds_str, 'rb') as f:
-                first_chunk = f.read(1024)
-                if is_binary_string(first_chunk):
-                    # likely netcdf file
-                    pass
-                elif is_cdl_file(ds_str, first_chunk):
-                    ds_str = self.generate_dataset(ds_str)
-                else:
-                    f.seek(0)
-                    doc = f.read()
+        if netcdf.is_netcdf(ds_str):
+            return Dataset(ds_str)
 
-        if doc is not None:
-            ds = self.process_doc(doc)
-        else:
-            # no doc? try the dataset constructor
-            ds = Dataset(ds_str)
-
-        return ds
+        raise ValueError("File is an unknown format")
 
     def scores(self, raw_scores):
         """
@@ -609,10 +574,10 @@ class CheckSuite(object):
         """
 
         def build_group(label=None, weight=None, value=None, sub=None):
-            label  = label
+            label = label
             weight = weight
-            value  = self._translate_value(value)
-            sub    = sub or []
+            value = self._translate_value(value)
+            sub = sub or []
 
             return Result(weight=weight,
                           value=value,
